@@ -58,12 +58,12 @@ def get_properties(file_path: Path) -> dict:
     Returns:
         dict: A dict with all properties from the specified file.
     """
-    with open(file_path, "r") as config_file:
+    with open(file_path, "r", encoding="iso8859_1") as config_file:
         config = properties_to_dict(config_file.read().splitlines())
     return config
 
 
-def set_properties(file_path: Path, properties: dict):
+def set_properties(file_path: Path, properties: dict) -> None:
     """Write a server.properties file from dict.
 
     The properties are written into the specified file in "KEY=VALUE" form.
@@ -80,10 +80,10 @@ def set_properties(file_path: Path, properties: dict):
 
     new_config = []
     for key, value in old_config.items():
-        new_config.append(f"{key}={value}")
+        new_config.append(f"{key}={value}\n")
 
-    with open(file_path, "w") as config_file:
-        config_file.write('\n'.join(new_config) + '\n')
+    with open(file_path, "w", encoding="iso8859_1") as config_file:
+        config_file.writelines(new_config)
 
 
 def accept_eula(instance_path: Path) -> bool:
